@@ -137,6 +137,7 @@ def _download_and_unpack_bundle(bundle_type):
     extraction_path = _get_extraction_path(bundle_type)
 
     # Unpack the bundle
+    LOGGER.info("Unpacking {}".format(bundle.name))
     if compression == 'tar.bz2':
         archive = tarfile.open(bundle.name, 'r:bz2')
         _store_bundle_files(archive.getnames(), extraction_path)
@@ -153,10 +154,7 @@ def _download_and_unpack_bundle(bundle_type):
 
     try:
         LOGGER.info('Unpacking {} to {}'.format(bundle.name, extraction_path))
-        print([m for m in archive.getmembers() if m.name != ''])
-        archive.extractall(
-            path=extraction_path,
-            members=[m for m in archive.getmembers() if m.name != ''])
+        archive.extractall(extraction_path)
     except Exception as err:
         LOGGER.error('Error when unpacking bundle: {}'.format(err))
     finally:
@@ -176,7 +174,7 @@ def _get_extraction_path(bundle_type):
     """
     path = '/'
     if sys.platform in ['win32', 'cygwin']:
-        path = 'C:'
+        path = 'C:\\'
 
     if not os.path.exists(path):
         LOGGER.debug('Created extraction path {}'.format(path))
@@ -390,7 +388,7 @@ def _store_bundle_files(filenames, extraction_path):
                 continue
 
             if sys.platform in ['win32', 'cygwin']:
-                filename = '{}\{}'.format(extraction_path, filename)
+                filename = '{}\\{}'.format(extraction_path, filename)
             else:
                 filename = '{}/{}'.format(extraction_path, filename)
 
